import {select} from 'd3-selection';

import config from 'ui/config';

import {mediaQuery} from 'ui/utils';

import {fetchCameraMetaData} from 'ui/web-services/camera-images';


const urlBase = `${config.MONITORING_LOCATION_CAMERA_ENDPOINT}/media/cameras/`;
const videoType = 'video/mp4';

/*
 * Fetch the camera meta data for siteno. If camera data is available render the video/image
 * elements as appropriate. Otherwise remove the node.
 * @param {DOM node} node
 * @param {String} siteno
 */
export const attachToNode = function(_, node, {siteno}) {
    fetchCameraMetaData(siteno).then((response) => {
        if (response.success && response.data.length) {
            const onDesktop = mediaQuery(config.USWDS_LARGE_SCREEN);
            const videoClass = onDesktop ? 'med-video' : 'small-video';
            const videoSuffix = onDesktop ? '_med.mp4' : '_small.mp4';
            const container = select(node).select('#camera-container');
            // Add a hidden video element to determine if video is supported on this browser
            const videoEl = container.append('video').attr('hidden', true);
            const isVideoSupported = videoEl.node().canPlayType(videoType) !== '' ;
            videoEl.remove();

            response.data.forEach((camera) => {
                const imagesBaseUrl = `${urlBase}${siteno}_${camera.videoNameBase}/${camera.videoNameBase}`;
                container.append('h3')
                    .text(camera.cameraName);
                container.append('p')
                    .text(camera.cameraDescription);
                const videoDiv = container.append('div');
                if (isVideoSupported) {
                    videoDiv.append('video')
                        .attr('class', `${videoClass} camera-video`)
                        .attr('title', `Timelapse video of ${camera.cameraName}`)
                        .attr('aria-label', `Timelapse video of ${camera.cameraName}`)
                        .attr('controls', true)
                        .attr('autoplay', true)
                        .append('source')
                            .attr('src', `${imagesBaseUrl}${videoSuffix}`)
                            .attr('type', videoType);
                } else {
                    videoDiv.append('img')
                        .attr('class', 'camera-most-recent-image')
                        .attr('title', `Most recent image at ${camera.cameraName}`)
                        .attr('aria-label', `Most recent image at ${camera.cameraName}`)
                        .attr('alt', `Most recent image at ${camera.cameraName}`)
                        .attr('src', `${imagesBaseUrl}_most_recent_frame.jpg`);
                }
                videoDiv.append('div').append('a')
                    .attr(
                        'href',
                        `${config.MONITORING_LOCATION_CAMERA_ENDPOINT}/camera/${siteno}_${camera.videoNameBase}`
                    )
                    .attr('class', 'usa-link')
                    .attr('target', '_blank')
                    .attr('rel', 'noopener')
                    .text('Details, interactive hydrograph, and image download');
            });

            node.removeAttribute('hidden');
        } else {
            node.remove();
        }
    });
};