import {select} from 'd3-selection';

import {MOCK_CAMERA_METADATA} from 'ui/mock-service-data';
import * as utils from 'ui/utils';
import * as cameraImagesService from 'ui/web-services/camera-images';

import {attachToNode} from './cameras';

describe('monitoring-location/components/cameras', () => {
    let div;
    let cameraDiv;
    const TEST_METADATA = JSON.parse(MOCK_CAMERA_METADATA);
    beforeEach(() => {
        div = select('body').append('div').attr('hidden', true);
        cameraDiv = div.append('div').attr('id', 'camera-container');
    });

    afterEach(() => {
        div.remove();
    });

    describe('Camera data is available and video is enabled', () => {
        beforeEach(() => {
            cameraImagesService.fetchCameraMetaData = jest.fn().mockReturnValue(Promise.resolve(TEST_METADATA));
            jest.spyOn(window.HTMLVideoElement.prototype, 'canPlayType').mockImplementation(() => 'probably');

        });

        it('Expect to display camera name, description, and video elements for med when on desktop', () => {
            utils.mediaQuery = jest.fn().mockReturnValue(true);
            attachToNode({}, div.node(), '05428500');
            return cameraImagesService.fetchCameraMetaData().then(() => {
                expect(cameraDiv.selectAll('h3').size()).toBe(1);
                expect(cameraDiv.select('h3').text()).toEqual(TEST_METADATA.data[0].cameraName);
                expect(cameraDiv.select('p').text()).toEqual(TEST_METADATA.data[0].cameraDescription);
                const videoEl = cameraDiv.select('video');
                expect(videoEl.attr('class')).toContain('med-video');
                expect(videoEl.attr('title')).toContain(TEST_METADATA.data[0].cameraName);
                expect(videoEl.select('source').attr('src')).toContain('_med');
            });
        });

        it('Expect to display camera name, description, and video elements for small when on mobile', () => {
            utils.mediaQuery = jest.fn().mockReturnValue(false);
            attachToNode({}, div.node(), '05428500');
            return cameraImagesService.fetchCameraMetaData().then(() => {
                expect(cameraDiv.selectAll('h3').size()).toBe(1);
                expect(cameraDiv.select('h3').text()).toEqual(TEST_METADATA.data[0].cameraName);
                expect(cameraDiv.select('p').text()).toEqual(TEST_METADATA.data[0].cameraDescription);
                const videoEl = cameraDiv.select('video');
                expect(videoEl.attr('class')).toContain('small-video');
                expect(videoEl.attr('title')).toContain(TEST_METADATA.data[0].cameraName);
                expect(videoEl.select('source').attr('src')).toContain('_small');
                expect(cameraDiv.selectAll('img').size()).toBe(0);
            });
        });
    });

    describe('Camera data is available but video is not supported', () => {
        beforeEach(() => {
            cameraImagesService.fetchCameraMetaData = jest.fn().mockReturnValue(Promise.resolve(TEST_METADATA));
            jest.spyOn(window.HTMLVideoElement.prototype, 'canPlayType').mockImplementation(() => '');

        });

        it('Expect to display images not video', () => {
            utils.mediaQuery = jest.fn().mockReturnValue(true);
            attachToNode({}, div.node(), '05428500');
            return cameraImagesService.fetchCameraMetaData().then(() => {
                expect(cameraDiv.select('h3').text()).toEqual(TEST_METADATA.data[0].cameraName);
                expect(cameraDiv.select('p').text()).toEqual(TEST_METADATA.data[0].cameraDescription);
                expect(cameraDiv.selectAll('video').size()).toBe(0);
            });
        });
    });

    describe('Camera data is not available', () => {
        beforeEach(() => {
            cameraImagesService.fetchCameraMetaData = jest.fn().mockReturnValue(Promise.resolve({success: false}));
        });

        it('Expect camera component to be removed', () => {
            attachToNode({}, div.node(), '05428500');
            return cameraImagesService.fetchCameraMetaData().then(() => {
                expect(select('body').selectAll('div').size()).toBe(0);
            });
        });
    });
});