import {select} from 'd3-selection';

import * as utils from 'ui/utils';

import {configureStore} from 'ml/store';

import {drawCursorSlider} from './cursor-slider';

describe('monitoring-location/components/daily-value-hydrograph/cursor-slider', () => {
utils.mediaQuery = jest.fn().mockReturnValue(true);

    const TEST_STATE = {
        dailyValueTimeSeriesData: {
            dvTimeSeries: {
                '12345': {
                    type: 'Feature',
                    id: '12345',
                    properties: {
                        phenomenonTimeStart: '2018-01-02',
                        phenomenonTimeEnd: '2018-01-05',
                        unitOfMeasureName: 'ft',
                        timeStep: ['2018-01-02', '2018-01-03', '2018-01-04', '2018-01-05'],
                        result: ['5.0', '4.0', '6.1', '3.2'],
                        approvals: [['Approved'], ['Approved'], ['Approved'], ['Approved']],
                        nilReason: [null, 'AA', null, null],
                        qualifiers: [null, null, ['ICE'], ['ICE']],
                        grades: [['50'], ['50'], ['60'], ['60']]
                    }
                }
            }
        },
        dailyValueTimeSeriesState: {
            currentDVTimeSeriesId: {
                min: null,
                mean: null,
                max: '12345'
            },
            dvGraphCursorOffset: 86400000
        },
        ui: {
            windowWidth: 1024,
            width: 800
        }
    };

    describe('drawCursorSlider', () => {
        let svg;
        let store;
        beforeEach(() => {
            svg = select('body').append('svg');
            store = configureStore(TEST_STATE);
        });

        afterEach(() => {
            svg.remove();
        });

        it('Creates a cursor slider', () => {
            drawCursorSlider(svg, store);

            const sliderGroup = svg.selectAll('.cursor-slider-group');
            expect(sliderGroup.size()).toBe(1);
            expect(sliderGroup.selectAll('.slider').size()).toBe(1);
        });
    });
});