import {lineMarker, rectangleMarker, textOnlyMarker} from 'd3render/markers';

import {getLegendMarkers} from './legend-data';

describe('monitoring-location/components/daily-value-hydrograph/legend-data', () => {

    const TEST_STATE = {
        dailyValueTimeSeriesData: {
            dvTimeSeries: {
                '12345': {
                    type: 'Feature',
                    id: '12345',
                    properties: {
                        phenomenonTimeStart: '2018-01-02',
                        phenomenonTimeEnd: '2018-01-05',
                        timeStep: ['2018-01-02', '2018-01-03', '2018-01-04', '2018-01-05'],
                        result: ['5.0', '4.0', '6.1', '3.2'],
                        approvals: [['Approved'], ['Approved'], ['Approved'], ['Approved']],
                        nilReason: [null, 'AA', null, null],
                        qualifiers: [null, ['ESTIMATED'], ['ICE'], ['ICE']],
                        grades: [['50'], ['50'], ['60'], ['60']]
                    }
                },
                '12346': {
                    type: 'Feature',
                    id: '12346',
                    properties: {
                        phenomenonTimeStart: '2018-01-02',
                        phenomenonTimeEnd: '2018-01-05',
                        timeStep: ['2018-01-02', '2018-01-03', '2018-01-04', '2018-01-05'],
                        result: ['6.0', '5.0', '7.1', '4.2'],
                        approvals: [['Approved'], ['Approved'], ['Approved'], ['Approved']],
                        nilReason: [null, 'AA', null, null],
                        qualifiers: [null, null, null, null],
                        grades: [['50'], ['50'], ['60'], ['60']]
                    }
                }
            }
        },
        dailyValueTimeSeriesState: {
            currentDVTimeSeriesId: {
                min: null,
                mean: '12345',
                max: '12346'
            }
        },
        ui: {
            windowWidth: 1024,
            width: 800
        }
    };

    describe('getLegendMarkers', () => {
        it('Should return no markers if no time series to show', () => {
            let newData = {
                ...TEST_STATE,
                dailyValueTimeSeriesData: {
                    ...TEST_STATE.dailyValueTimeSeriesData,
                    dvTimeSeries: {}
                }
            };

            expect(getLegendMarkers(newData)).toEqual([]);
        });

        it('Should return markers for the selected variable', () => {
            const result = getLegendMarkers(TEST_STATE);

            expect(result).toHaveLength(2);
            expect(result[0]).toHaveLength(4);
            expect(result[0]).toContainEqual({
                type: textOnlyMarker,
                domId: null,
                domClass: null,
                text: 'Mean:'
            });
            expect(result[0]).toContainEqual({
                type: lineMarker,
                domId: null,
                domClass: 'line-segment approved mean',
                text: 'Approved'

            });
            expect(result[0]).toContainEqual({
                type: lineMarker,
                domId: null,
                domClass: 'line-segment estimated mean',
                text: 'Estimated'

            });
            expect(result[0]).toContainEqual({
                type: rectangleMarker,
                domId: null,
                domClass: 'mask mask-0',
                text: 'Ice affected',
                fill: 'url(#dv-mean-masked-pattern)'

            });

            expect(result[1]).toHaveLength(2);
            expect(result[1]).toContainEqual({
                type: textOnlyMarker,
                domId: null,
                domClass: null,
                text: 'Maximum:'
            });
            expect(result[1]).toContainEqual({
                type: lineMarker,
                domId: null,
                domClass: 'line-segment approved max',
                text: 'Approved'

            });
        });
    });
});