import {select} from 'd3-selection';

import {link} from 'ui/lib/d3-redux';

import {drawLoadingIndicator} from 'd3render/loading-indicator';

import {hasAnyVisibleData} from './selectors/time-series-data';
import {getMainLayout} from './selectors/layout';

const updateNoDataOverlay = function(container, store) {
    const noDataOverlay = container.select('div');
    const hasVisibleData = hasAnyVisibleData(store.getState());
    if (hasVisibleData && noDataOverlay.size()) {
        noDataOverlay.remove();
    } else if (!hasVisibleData && !noDataOverlay.size()) {
        const overlayDiv = container.append('div')
            .call(link(store, (elem, layout) => {
                elem.style('transform', `translateY(${layout.height / 2}px)`);
            }, getMainLayout));
        overlayDiv.append('div').text('No data available');
    }
};

/*
 * Makes the loading indicator visible if isLoading otherwise removes the loading indicator and
 * adds/removes the "no data" overlay as appropriate.
 * @param {Boolean} isLoading
 * @param {Redux store} store - If missing, the loading container position is not centered and
 * the "no data" overlay is not updated. In practice, the store is not passed in until the data
 * has been loaded once (at hydrograph component initialization). Until then the graph has not been
 * rendered, therefore the loading indicator does not need to be moved.
 */
export const showDataIndicators = function(isLoading, store) {
    const loadingContainer = select('#hydrograph-loading-indicator-container')
        .call(drawLoadingIndicator, {
            showLoadingIndicator: isLoading
        });
    if (isLoading && store) {
        const layout = getMainLayout(store.getState());
        const translateX = layout.width / 2 - layout.margin.left - layout.margin.right;
        const translateY = layout.height  / 2 - layout.margin.top - layout.margin.bottom;
        loadingContainer.style(
            'transform',
            `translate(${translateX}px, ${translateY}px)`);
    } else  if (!isLoading && store) {
        select('#hydrograph-no-data-overlay').call(updateNoDataOverlay, store);
    }
};