import {createSelector} from 'reselect';

import {getFloodLevels} from 'ml/selectors/flood-data-selector';

const STAGES = {
    action_stage: {
        label: 'Action stage',
        class: 'action-stage'
    },
    flood_stage: {
        label: 'Minor flood stage',
        class: 'minor-flood-stage'
    },
    moderate_flood_stage: {
        label: 'Moderate flood stage',
        class: 'moderate-flood-stage'
    },
    major_flood_stage: {
        label: 'Major flood stage',
        class: 'major-flood-stage'
    }
};

/*
 * Returns a selector function which returns an array of {Object}. Each object
 * represents a flood level and includes the properties:
 *      @prop {Number} value - the value of the flood level
 *      @prop {String} displayValue - the string value (preserves significant digits)
 *      @prop {String} label - a human friendly label for the flood level
 *      @prop {String} class - a class to be used to decorate the flood level
 */
export const getFloodLevelData = createSelector(
    getFloodLevels,
    levels => {
        const result = [];
        if (levels) {
            Object.keys(STAGES).forEach(stage => {
                if (levels[stage]) {
                    result.push({
                        ...STAGES[stage],
                        displayValue: levels[stage],
                        value: parseFloat(levels[stage])
                    });
                }
            });
        }
        return result;
    }
);