import {format} from 'd3-format';

import * as utils from 'ui/utils';

import {getMainLayout, ASPECT_RATIO} from './layout';

describe('monitoring-location/components/hydrograph/layout module', () => {
    utils.mediaQuery = jest.fn().mockReturnValue(true);

    it('Should return the width and height with the predefined ASPECT_RATIO for the main layout', () => {
        const layout = getMainLayout.resultFunc(200, 600, {
            tickValues: [5, 10, 15],
            tickFormat: format('d')
        });

        expect(layout.width).toEqual(200);
        expect(layout.height).toEqual(200 * ASPECT_RATIO);
        expect(layout.windowWidth).toEqual(600);
        expect(layout.margin.bottom).toEqual(5);
        expect(layout.margin.top).toEqual(25);
        expect(layout.margin.left).toEqual(45);
        expect(layout.margin.right).toEqual(25);
    });

    it('expects that margins will adjust for secondary y-axis', () => {
        const layout = getMainLayout.resultFunc(200, 600, {
            tickValues: [5, 10, 15],
            tickFormat: format('d')
        }, '00065');

        expect(layout.width).toEqual(200);
        expect(layout.height).toEqual(200 * ASPECT_RATIO);
        expect(layout.windowWidth).toEqual(600);
        expect(layout.margin.bottom).toEqual(5);
        expect(layout.margin.top).toEqual(25);
        expect(layout.margin.left).toEqual(45);
        expect(layout.margin.right).toEqual(45);
    });
});
