import {createSelector} from 'reselect';
import {DateTime} from 'luxon';
import memoize from 'fast-memoize';

import {getStatisticsData} from 'ml/selectors/hydrograph-data-selector';

/*
 * Selector function that gets the statistics for a given day and returns an
 * array containing an object for each method with statistics available
 * @param {Date} a Date object for the day to be fetched
 * @returns [Array {Object}]
 * 
 */
export const getDailyStatistics = memoize( (date) => createSelector(
    getStatisticsData,
    (stats) => {
        
        if (!stats || !Object.keys(stats).length) {
            return [];
        }
        let statsDataArray = Object.keys(stats).map((method) => stats[method]);
        
        const dateObj = DateTime.fromJSDate(date);

        const isLeapYear = dateObj.isInLeapYear;
        
        const dayInYear = dateObj.ordinal;
        // There is a dedicated index in stats array for Feb 29
        if (!isLeapYear && date.getMonth() > 1) {
            return statsDataArray.map((methodArray) => methodArray[dayInYear]);
        }
        return statsDataArray.map((methodArray) => methodArray[dayInYear - 1]);
    }));