import config from 'ui/config';

import {getDailyStatistics} from './statistics';

import {TEST_STATS_DATA} from '../mock-hydrograph-state';

describe('monitoring-location/components/hydrograph/selectors/statistics-table', () => {
    config.locationTimeZone = 'America/Chicago';

    const TEST_STATE = {
        hydrographData: {
            statisticsData: TEST_STATS_DATA
        }
    };

    describe('getDailyStatistics', () => {
        it('Returns empty array if no stats data exists', () => {
            expect(getDailyStatistics(new Date(2020, 0, 1))({
                ...TEST_STATE,
                hydrographData: {
                    statisticsData: {}
                }

            })).toStrictEqual([]);
        });

        it('Returns array of data objects of correct day', () => {
            expect(getDailyStatistics(new Date(2020, 0, 2))({
                ...TEST_STATE,
                hydrographData: {
                    statisticsData: TEST_STATS_DATA
                }
                })).toStrictEqual([{
                    month_nu: 2,
                    day_nu: 25,
                    p50_va: 160.2,
                    ts_id: '90649',
                    loc_web_ds: 'Method2',
                    begin_yr: '2011',
                    end_yr: '2020',
                    max_va_yr: '2020',
                    max_va: '2730',
                    min_va_yr: '2006',
                    min_va: '550.5',
                    mean_va: '1530',
                    p05_va: '',
                    p10_va: '610',
                    p20_va: '880',
                    p25_va: '1000',
                    p75_va: '2240',
                    p80_va: '2640',
                    p90_va: '2710',
                    p95_va: ''},

                    {month_nu: 2,
                    day_nu: 25, 
                    p50_va: 16.2, 
                    ts_id: '153885', 
                    loc_web_ds: 'Method1', 
                    begin_yr: '2011', 
                    end_yr: '2020', 
                    max_va_yr: '2020',
                    max_va: '273', 
                    min_va_yr: '2006', 
                    min_va: '55.5', 
                    mean_va: '153', 
                    p05_va: '', 
                    p10_va: '61', 
                    p20_va: '88', 
                    p25_va: '100',
                    p75_va: '224', 
                    p80_va: '264', 
                    p90_va: '271', 
                    p95_va: ''}
                ]);
            });

            it('Returns array index of correct day on leap years', () => {
                expect(getDailyStatistics(new Date(2020, 2, 1))({
                    ...TEST_STATE,
                    hydrographData: {
                        statisticsData: {
                            '153885': Array.from(Array(65).keys())
                        }
                    }
                    })).toStrictEqual([60]);
                });

            it('Returns array index of correct day on non-leap years', () => {
                expect(getDailyStatistics(new Date(2021, 2, 1))({
                    ...TEST_STATE,
                    hydrographData: {
                        statisticsData: {
                            '153885': Array.from(Array(65).keys())
                        }
                    }
                    })).toStrictEqual([60]);
                });
    });

});