import {createSelector} from 'reselect';

import {getMainYScale} from './scales';
import {getThresholds} from 'ml/selectors/hydrograph-data-selector';
import {getSelectedMethodDescription, getPrimaryParameterUnitCode} from './time-series-data';


/**
 * Selector function that check which thresholds are within the graph y axis range and returns them
 * @param {String} getPrimaryParameterUnitCode - the text for the units
 * @param {String} getSelectedMethodDescription - the text value of the current sampling method, often and empty string
 * @param {function} getMainYScale - returns the start an end of the y scale
 * @param {Object} getThresholds - the cleaned threshold values returned from sensor things
 * @return {Function} - returns an {Object} containing details about the thresholds in that are in range of the y axis
 */
export const getThresholdsInRange = createSelector(
    getPrimaryParameterUnitCode,
    getSelectedMethodDescription,
    getMainYScale,
    getThresholds,
    (unitCode, selectedMethodDescription, yScale, thresholds) => {
        const [yStart, yEnd] = yScale.domain();

        let thresholdsInRange = [];
        if (thresholds && selectedMethodDescription) {
            thresholds.operatingLimits.forEach(limitSet => {
                if (limitSet.methodDescription === selectedMethodDescription.methodDescription) {
                    limitSet.thresholdDetails.forEach(detail => {
                        if (detail.referenceValue !== '' && detail.referenceValue > yStart && detail.referenceValue < yEnd) {
                            const thresholdClass = detail.referenceCode.split('Operational ')[1].toLowerCase().split(' ').join('');
                            thresholdsInRange.push({
                                code: detail.referenceCode,
                                thresholdClass: thresholdClass,
                                value: detail.referenceValue,
                                unit: unitCode
                            });
                        }
                    });
                }
            });
         }
        return thresholdsInRange;
    });