import {line as d3Line} from 'd3-shape';

/*
 * Renders available threshold lines on the graph.
 * @param {D3 selection for svg or group} the element containing the graph
 * @param {D3 scale} xscale - D3 function defining the domain of the graph
 * @param {D3 scale} yscale - D3 function defining the range of the graph
 * @param {Array of Objects} thresholds - groups of thresholds containing individual threshold descriptions and values
 */
export const drawThresholdLines = function(svg, {xscale, yscale, thresholds}) {
    svg.select('#threshold-lines').remove();
    const container = svg.append('g')
        .lower()
        .attr('id', 'threshold-lines');
    const xRange = xscale.range();

    if (thresholds.length) {
        thresholds.forEach(limit => {
            const group = container.append('g');
            const yRange = yscale(limit.value);
            const thresholdLine = d3Line()([[xRange[0], yRange], [xRange[1], yRange]]);
            group.append('path')
                .classed('threshold-data-series', true)
                .classed(limit.thresholdClass, true)
                .attr('d', thresholdLine);
        });
    }
};