import {select} from 'd3-selection';
import {scaleLinear} from 'd3-scale';

import {drawThresholdLines} from './threshold-lines';

describe('monitoring-location/components/hydrograph/threshold-lines', () => {
    let svg;
    beforeEach(() => {
        svg = select('body').append('svg');
    });

    afterEach(() => {
        svg.remove();
    });
    describe('drawThresholdLines', () => {
        let xscale, yscale;
        const TEST_THRESHOLDS = [
            {
                'code': 'Operational limit - low-Public',
                'thresholdClass': 'limit-low-public',
                'value': 3,
                'unit': 'mg/l'
            }
        ];
        beforeEach(() => {
            xscale = scaleLinear()
                .domain([1489000000000, 1500000000000])
                .range([0, 100]);
            yscale = scaleLinear()
                .domain([4, 11.5])
                .range([0, 100]);
        });

        it('Does not render threshold levels if none are defined', () => {
            drawThresholdLines(svg, {
                xscale,
                yscale,
                thresholds: []
            });
            const group = svg.select('#threshold-lines');
            expect(group.select('g').size()).toBe(0);
        });

        it('Renders thresholds when available', () => {
            drawThresholdLines(svg, {
                xscale,
                yscale,
                thresholds: TEST_THRESHOLDS
            });
            const group = svg.select('#threshold-lines');
            expect(group.select('.limit-low-public').size()).toBe(1);
        });

        it('Will remove thresholds before a new render', () => {
            drawThresholdLines(svg, {
                xscale,
                yscale,
                thresholds: TEST_THRESHOLDS
            });
            const groupWithThreshold = svg.select('#threshold-lines');
            expect(groupWithThreshold.select('.limit-low-public').size()).toBe(1);

            drawThresholdLines(svg, {
                xscale,
                yscale,
                thresholds: []
            });

            const groupWithoutThreshold = svg.select('#threshold-lines');
            expect(groupWithoutThreshold.select('.limit-low-public').size()).toBe(0);
        });
    });
});