import {mount} from '@vue/test-utils';
import {bindActionCreators} from 'redux';
import ReduxConnectVue from 'redux-connect-vue';
import {createStructuredSelector} from 'reselect';
import {configureStore} from 'ml/store';
import * as utils from 'ui/utils';
import {Actions as uiActions} from 'ml/store/ui-state';
import {TEST_PRIMARY_IV_DATA, TEST_CURRENT_TIME_RANGE} from '../mock-hydrograph-state';

import CursorSlider from './cursor-slider.vue';

describe('monitoring-location/components/hydrograph/cursor-slider', () => {
    const TEST_STATE = {
        hydrographData: {
            primaryIVData: TEST_PRIMARY_IV_DATA,
            currentTimeRAnge: TEST_CURRENT_TIME_RANGE
        },
        hydrographState: {
            graphCursorOffset: 500000
        },
        ui: {
            windowWidth: 1300,
            width: 990
        }
    };

    let store;
    let wrapper;

    describe('drawCursorSlider', () => {
        utils.mediaQuery = jest.fn().mockReturnValue(true);
        beforeEach(() => {
            store = configureStore(TEST_STATE);

            wrapper = mount(CursorSlider, {
                global: {
                    plugins: [
                        [ReduxConnectVue, {
                            store,
                            mapDispatchToPropsFactory: (actionCreators) => (dispatch) => bindActionCreators(actionCreators, dispatch),
                            mapStateToPropsFactory: createStructuredSelector
                        }]
                    ],
                    provide: {
                        store: store
                    }
                }
            });
        });

        it('Creates a cursor slider', async() => {
            const sliderGroup = wrapper.findAll('.cursor-slider-group');
            expect(sliderGroup).toHaveLength(1);
            expect(wrapper.vm.group.getAttribute('transform')).toContain('translate');
        });

        it('Expects that changing the ui width will change the viewBox and transforms', async() => {
            const viewBox = wrapper.find('.cursor-slider-svg').attributes('viewBox');
            const sliderGroup = wrapper.find('.cursor-slider-group');
            utils.mediaQuery.mockReturnValue(false);
            store.dispatch(uiActions.resizeUI(400, 350));
            await wrapper.vm.$nextTick();

            expect(wrapper.find('.cursor-slider-svg').attributes('viewBox')).not.toEqual(viewBox);
            expect(wrapper.find('.cursor-slider-group').attributes('translate')).not.toEqual(sliderGroup);
        });
    });
});