import {mount} from '@vue/test-utils';

import config from 'ui/config';

import MethodPicker from './method-picker.vue';

describe('monitoring-location/components/hydrograph/vue-components/method-picker', () => {
    config.STATIC_URL = 'https://fakeserver.com/static/';

    const TEST_SORTED_IV_METHODS = {
        'parameterCode': '00300',
        'methods': [{
            'pointCount': 672,
            'lastPoint': {'value': '5.5', 'qualifiers': ['P'], 'dateTime': 1655135100000},
            'methodID': '57501',
            'methodDescription': '[YSI EXO]'
        }, {
            'pointCount': 5,
            'lastPoint': null,
            'methodID': '57481',
            'methodDescription': 'Discontinued Mar. 11, 2015'
        }, {
            'pointCount': 0,
            'lastPoint': null,
            'methodID': '57487',
            'methodDescription': 'FROM NR BANK MONITOR, [Discontinued June 30, 2015]'
        }]
    };

    it('Expects that the expected html is rendered', () => {
        const wrapper = mount(MethodPicker, {
            props: {
                sortedIvMethods: TEST_SORTED_IV_METHODS
            }
        });

        expect(wrapper.find('.usa-label').attributes('for')).toBe('method-picker-00300');
        expect(wrapper.find('.usa-icon').html()).toContain(config.STATIC_URL);
        expect(wrapper.find('.no-data-points-note').exists()).toBe(true);
        expect(wrapper.find('select').attributes('id')).toBe('method-picker-00300');
        const options = wrapper.findAll('option');
        expect(options).toHaveLength(3);
        expect(options[0].attributes('value')).toBe('57501');
        expect(options[0].attributes('disabled')).not.toBeDefined();
        expect(options[0].text()).toBe('[YSI EXO]');
        expect(options[1].attributes('value')).toBe('57481');
        expect(options[1].attributes('disabled')).not.toBeDefined();
        expect(options[1].text()).toBe('Discontinued Mar. 11, 2015');
        expect(options[2].attributes('value')).toBe('57487');
        expect(options[2].attributes('disabled')).toBeDefined();
        expect(options[2].text()).toBe('FROM NR BANK MONITOR, [Discontinued June 30, 2015]');
    });

    it('Should not show the no data note if all methods have points', () => {
        const wrapper = mount(MethodPicker, {
            props: {
                sortedIvMethods: {
                    parameterCode: TEST_SORTED_IV_METHODS.parameterCode,
                    methods: [TEST_SORTED_IV_METHODS.methods[0], TEST_SORTED_IV_METHODS.methods[1]]
                }
            }
        });

        expect(wrapper.find('.no-data-points-note').exists()).toBe(false);
    });

    it('Expects the selectMethod event to be emitted if an option is selected', async() => {
        const wrapper = mount(MethodPicker, {
            props: {
                sortedIvMethods: TEST_SORTED_IV_METHODS
            }
        });

        const select = wrapper.find('select');
        select.element.value = '57481';
        await select.trigger('change');

        expect(wrapper.emitted().selectMethod[0]).toEqual(['57481']);
    });
});