import {mount} from '@vue/test-utils';

import config from 'ui/config';

import ParameterSelectionExpansionControl from './parameter-selection-expansion-control.vue';

describe('monitoring-location/components/hydrograph/vue-components/', () => {
    config.STATIC_URL = 'https://fakeserver.com/static/';

    it('Renders the expected components when isExpanded is default (false)', () => {
        const wrapper = mount(ParameterSelectionExpansionControl, {
            props: {
                parameterCode: '00060',
                idForExpansionRow: 'my-test-row'
            }
        });

        const toggleContainer = wrapper.find('.expansion-toggle');
        expect(toggleContainer.attributes('aria-expanded')).toBe('false');
        expect(toggleContainer.attributes('aria-controls')).toBe('my-test-row');
        const svg = toggleContainer.find('svg');
        expect(svg.attributes('aria-label')).toBe('click to expand details');
        expect(svg.find('use').attributes('href')).toBe(
            'https://fakeserver.com/static/img/sprite.svg#expand_more');
    });

    it('Renders the expected components when isExpanded is true', () => {
        const wrapper = mount(ParameterSelectionExpansionControl, {
            props: {
                parameterCode: '00060',
                isExpanded: true,
                idForExpansionRow: 'my-test-row'
            }
        });

        const toggleContainer = wrapper.find('.expansion-toggle');
        expect(toggleContainer.attributes('aria-expanded')).toBe('true');
        expect(toggleContainer.attributes('aria-controls')).toBe('my-test-row');
        const svg = toggleContainer.find('svg');
        expect(svg.attributes('aria-label')).toBe('click to hide details');
        expect(svg.find('use').attributes('href')).toBe(
            'https://fakeserver.com/static/img/sprite.svg#expand_less');
    });

    it('emits toggleRowVisibility event when the expansion toggle is clicked when not expanded', async() => {
        const wrapper = mount(ParameterSelectionExpansionControl, {
            props: {
                parameterCode: '00060',
                idForExpansionRow: 'my-test-row'
            }
        });
        const toggleContainer = wrapper.find('.expansion-toggle');
        await toggleContainer.trigger('click');

        let emittedEvents = wrapper.emitted().toggleExpansionRow;
        expect(emittedEvents).toHaveLength(1);
        expect(emittedEvents[0]).toEqual(['00060', true]);
   });

    it('emits toggleRowVisibility event when the expansion toggle is clicked when expanded', async() => {
        const wrapper = mount(ParameterSelectionExpansionControl, {
            props: {
                parameterCode: '00060',
                idForExpansionRow: 'my-test-row',
                isExpanded: true
            }
        });
        const toggleContainer = wrapper.find('.expansion-toggle');
        await toggleContainer.trigger('click');

        let emittedEvents = wrapper.emitted().toggleExpansionRow;
        expect(emittedEvents).toHaveLength(1);
        expect(emittedEvents[0]).toEqual(['00060', false]);
   });
});