import {shallowMount} from '@vue/test-utils';

import config from 'ui/config.js';

import SelectActions from './select-actions.vue';
import TimeSpanControls from './time-span-controls.vue';
import DownloadData from './download-data.vue';


describe('monitoring-location/components/hydrograph/vue-components/select-actions', () => {
    describe('tests with IV or GW data', () => {
        let wrapper;

        beforeEach(() => {
            config.ivPeriodOfRecord = {
                '32295': {
                    'begin_date': '2014-09-05',
                    'end_date': '2022-06-22'
                },
                '00400': {
                    'begin_date': '2007-10-01',
                    'end_date': '2022-06-22'
                }
            };
            wrapper = shallowMount(SelectActions);
        });

        it('expects the component to be rendered with the correct sub components', () => {
            expect(wrapper.findAllComponents(TimeSpanControls)).toHaveLength(1);
            expect(wrapper.findAllComponents(DownloadData)).toHaveLength(1);
        });

        it('expects that clicking the buttons in the button row will show or hide components', async() => {
            expect(wrapper.findComponent(TimeSpanControls).isVisible()).toBe(false);
            expect(wrapper.findComponent(DownloadData).isVisible()).toBe(false);

            expect(wrapper.findAll('button')).toHaveLength(2);
            const changeTimeSpanButton = wrapper.findAll('button')[0];
            const retrieveDataButton = wrapper.findAll('button')[1];

            expect(changeTimeSpanButton.text()).toBe('Change time span');
            expect(retrieveDataButton.text()).toBe('Retrieve data');

            await changeTimeSpanButton.trigger('click');
            expect(wrapper.findComponent(TimeSpanControls).isVisible()).toBe(true);
            expect(wrapper.findComponent(DownloadData).isVisible()).toBe(false);

            await retrieveDataButton.trigger('click');
            expect(wrapper.findComponent(TimeSpanControls).isVisible()).toBe(false);
            expect(wrapper.findComponent(DownloadData).isVisible()).toBe(true);

            await retrieveDataButton.trigger('click');
            expect(wrapper.findComponent(TimeSpanControls).isVisible()).toBe(false);
            expect(wrapper.findComponent(DownloadData).isVisible()).toBe(false);
        });
    });

    describe('tests with NO IV or GW data', () => {
        let wrapper;

        beforeEach(() => {
            config.ivPeriodOfRecord = null;
            config.gwPeriodOfRecord = null;
            wrapper = shallowMount(SelectActions);
        });

        it('expects that only the retreive data button will show if there is no IV or GW data at a monitoring location', async() => {
            expect(wrapper.findComponent(TimeSpanControls).isVisible()).toBe(false);
            expect(wrapper.findComponent(DownloadData).isVisible()).toBe(false);
            expect(wrapper.findAll('button')).toHaveLength(1);

            const retrieveDataButton = wrapper.find('button');

            expect(retrieveDataButton.text()).toBe('Retrieve data');

            await retrieveDataButton.trigger('click');
            expect(wrapper.findComponent(TimeSpanControls).isVisible()).toBe(false);
            expect(wrapper.findComponent(DownloadData).isVisible()).toBe(true);

            await retrieveDataButton.trigger('click');
            expect(wrapper.findComponent(TimeSpanControls).isVisible()).toBe(false);
            expect(wrapper.findComponent(DownloadData).isVisible()).toBe(false);
        });
    });
});