import {select} from 'd3-selection';
import {enableFetchMocks, disableFetchMocks} from 'jest-fetch-mock';
import mockConsole from 'jest-mock-console';

import {drawMonitoringLocationMarkerLegend, drawCircleMarkerLegend, drawFIMLegend} from './legend';

describe('monitoring-location/components/map/legend module', () => {
    let listContainer;
    let restoreConsole;

    beforeEach(() => {
        enableFetchMocks();
        restoreConsole = mockConsole();
        listContainer = select('body').append('div');
    });

    afterEach(() => {
        listContainer.remove();
        disableFetchMocks();
        restoreConsole();
    });

    describe('drawMonitoringLocationMarkerLegend', () => {
        it('Draws an marker image', () => {
            drawMonitoringLocationMarkerLegend(listContainer);

            expect(listContainer.select('#site-legend-list').size()).toBe(1);
            expect(listContainer.select('img').size()).toBe(1);
        });
    });

    describe('drawCircleMarkerLegend', () => {
        it('Draws a circle marker legend', () => {
            drawCircleMarkerLegend(listContainer, 'red', 0.5, 'My circle marker');

            let circleSpan = listContainer.select('.dot');
            expect(circleSpan.size()).toBe(1);
            expect(circleSpan.style('background-color')).toEqual('red');
            expect(circleSpan.style('opacity')).toEqual('0.5');
            expect(listContainer.select('span:nth-child(2)').text()).toEqual('My circle marker');
        });
    });

    describe('drawFIMLegend', () => {
        const MOCK_RESP =
            `{"layers": [{
                "layerId":0,
                "layerName":".",
                "layerType":"Feature Layer",
                "minScale":0,
                "maxScale":0,
                "legend":[{
                    "label":"",
                    "url":"a1a90aac95d70de618d5bba56c4e03e9",
                    "imageData":"fakeData",
                    "contentType":"image/png",
                    "height":20,
                    "width":20}]
                 }, {
                "layerId":1,
                "layerName":"Real name",
                "layerType":"Feature Layer",
                "minScale":0,
                "maxScale":0,
                "legend":[{
                    "label":"",
                    "url":"a1a90aac95d70de618d5bba56c4e03e9",
                    "imageData":"fakeData2",
                    "contentType":"image/png",
                    "height":20,
                    "width":20}]}
                    ]}`;

        beforeEach(() => {
            fetch.mockResponse(MOCK_RESP, {status: 200});
            drawFIMLegend(listContainer, true);
        });

        it('drawFIMLegend with FIM available true fetches the three sets of legend info', () => {
            expect(fetch.mock.calls).toHaveLength(3);
        });

        it('drawFIMLegend with FIM available add the FIM legend list to the control', () => {
            expect(listContainer.select('#fim-legend-list').size()).toBe(1);
        });

        it('Calling drawFIMLegend a second time with available set to false cause the fim legend list to be removed', () => {
            drawFIMLegend(listContainer, false);

            expect(listContainer.select('#fim-legend-list').size()).toBe(0);
        });
    });
});
